*Ultima actualización: 28 febrero 2022

* Las bases de datos del cuestionario ampliado del Censo de Población y vivienda 2020
* se pueden descargar en la página de internet del INEGI
*https://www.inegi.org.mx/programas/ccpv/2020/#Microdatos.

********************************************************************************
* Contenido del archivo:
* 0. Directorios de trabajo
* 1. Pegado de bases de datos
* 2. NBI 
* 3. Educación
* 4. Salud y Seguridad Social
* 5. Tiempo
* 6. Cálculo de indicador de NBI
********************************************************************************
********************************************************************************
* Módulo 0. Directorios de trabajo
********************************************************************************
*Se recomienda crear las siguientes carpetas y colocarlas en la raíz de la unidad C de su equipo.  

*Globals Directorio de bases

gl ruta=       "C:\CENSO2020\AMPLIADO"
gl bases=      "$ruta/BASES"
gl modificadas="$ruta/MODIFICADAS"
gl trabajo=    "$ruta/TRABAJO"
gl tmp=        "$ruta/TMP"
gl final=      "$ruta/FINAL"
set more off

* En la carpeta "BASES", colocar los siguientes archivos:
* Personas09 y Viviendas09.dta

********************************************************************************
* Módulo 1. Pegado de bases de datos
********************************************************************************

use "$bases/Viviendas09.dta", clear
destring ent-nom_loc cobertura-tamloc_e, replace
save "$modificadas/viviendas.dta", replace

use "$bases/Personas09.dta", clear
destring ent-nom_loc cobertura-tamloc_e, replace
save "$modificadas/poblacion.dta", replace

*Etiquetar y crear variables de localidad, pegar con la base de vivienda y 
*filtrar solo por familiares directos al interior del hogar.

*Primero seleccionar variables de vivienda
use "$modificadas/viviendas.dta", clear

*Generar etiquetas para la variable Tamaño de localidad (tamloc)
label define tamloc 1 "Menos de 2500 habitantes" 2 "De 2500 a 14999 habitantes"               ///
3 "De 15000 a 49999 habitantes" 4 "De 50000 a 99999 habitantes" 5 "100 000 y más habitantes"
destring tamloc, replace 
label    values  tamloc tamloc

*Generar variable tipo de localidad
gen ur_rur_2500=.
*rural
replace ur_rur_2500=1 if tamloc==1
*urbano
replace ur_rur_2500=2 if tamloc>=2

label define ur_rur_2500 1 "Rural" 2 "Urbano"
label value ur_rur_2500 ur_rur_2500

*Se etiquetan las entidades
label define ent  9 "Ciudad de México"
label value ent ent

*Alcaldias de la Ciudad de México
gen alcaldia=.
replace alcaldia= 2 if (ent==9 & mun== 2)
replace alcaldia= 3 if (ent==9 & mun== 3)
replace alcaldia= 4 if (ent==9 & mun== 4)
replace alcaldia= 5 if (ent==9 & mun== 5)
replace alcaldia= 6 if (ent==9 & mun== 6)
replace alcaldia= 7 if (ent==9 & mun== 7)
replace alcaldia= 8 if (ent==9 & mun== 8)
replace alcaldia= 9 if (ent==9 & mun== 9)
replace alcaldia=10 if (ent==9 & mun==10)
replace alcaldia=11 if (ent==9 & mun==11)
replace alcaldia=12 if (ent==9 & mun==12)
replace alcaldia=13 if (ent==9 & mun==13)
replace alcaldia=14 if (ent==9 & mun==14)
replace alcaldia=15 if (ent==9 & mun==15)
replace alcaldia=16 if (ent==9 & mun==16)
replace alcaldia=17 if (ent==9 & mun==17)

*Etiquetado de las alcaldias de la Ciudad de México
label define alcaldia 10 "Álvaro Obregón"    2 "Azcapotzalco" 14 "Benito Juárez"       ///
 3 "Coyoacán"    4 "Cuajimalpa de Morelos"  15 "Cuauhtémoc"    5 "Gustavo A. Madero"   ///
 6 "Iztacalco"   7 "Iztapalapa"              8 "La Magdalena Contreras"                ///  
16 "Miguel Hidalgo" 9 "Milpa Alta" 11 "Tláhuac" 12 "Tlalpan"  17 "Venustiano Carranza" ///
13 "Xochimilco" 
label value alcaldia alcaldia

save "$trabajo/viviendas_variables.dta", replace

**********
* Trabajar la base de población
**********

use "$modificadas/poblacion.dta", clear

*Eliminar los folios de los que no son miembros de la familia en el hogar
destring parentesco, replace
drop if  parentesco>=600 & parentesco <720
drop if  parentesco==999

*Generar la variable "tamaño de hogar"

gen tam_hog=1 
collapse (sum) tam_hog, by(id_viv)
*Guardar base
save "$tmp/tamano_hogar.dta", replace
use  "$trabajo/viviendas_variables.dta", clear

*Se seleccionan las variables creados y de diseño muestral y se genera una nueva base
keep id_viv nom_mun nom_ent ur_rur_2500 factor upm tamloc estrato

merge 1:1 id_viv using "$tmp/tamano_hogar.dta"
tab _merge
drop _merge

*Generar un nuevo factor de expansión de individuo
gen factorxind = factor * tam_hog
save "$tmp/factexp.dta", replace


*Pegar el nuevo factor de expansión a la base de hogares con variables
use "$trabajo/viviendas_variables.dta", clear

merge 1:1 id_viv using "$tmp/factexp.dta"
tab _merge
drop _merge
*Guardar en una nueva base de datos
save "$final/hogaresNBI.dta", replace

********************************************************************************
* Módulo 2. NBI, de acuerdo con la metodología del MMIP, la dimensión de las NBI
* se calcula con los siguientes componentes. 
*
*   2.1 Construcción y cálculo del indicador de espacio y calidad de la vivienda
*   2.2 Construcción y cálculo del indicador de bienes durables
*   2.3 Construcción y cálculo del indicador de adecuación sanitaria
*   2.4 Construcción y cálculo del indicador de servicio telefónico
*   2.5 Construcción y cálculo del indicador de servicio de internet
*   2.6 Construcción y cálculo del indicador de acceso a internet en la vivienda 
*   2.7 Archivo con los  Indicadores de Adecuación de la Vivienda-NBI
*
********************************************************************************

use "$final/hogaresNBI.dta", replace

********************************************************************************
*2.1 Construcción y cálculo del indicador de espacio y calidad de la vivienda
********************************************************************************

***
*2.1.1 Calidad de la vivienda, se elaboran indicadores parciales que miden la 
*      calidad de muros, pisos y techos de las viviendas
****
************************************
*Pared 

gen       AMj=0
*Material de desecho o lámina de cartón=0
replace   AMj=0     if  (paredes==1 | paredes==2)
*Lámina de asbesto o metálica, carrizo, bambú o palma, embarro o bajareque
replace   AMj=0.25  if  (paredes >2 & paredes <6)
*Madera, adobe
replace   AMj=0.6   if  (paredes==6 | paredes==7)
*Tabique, ladrillo, block, piedra, cantera, cemento o concreto
replace   AMj=1     if   paredes==8 
label var AMj "Adecuación de muros"

************************************
*Techos

gen       ATj=0
*Material de desecho o lámina de cartón = 0
replace   ATj=0    if (techos==1  | techos==2)
*Lámina metálica, de asbesto de fibrocemento, palma o paja, madera o tejamanil o 
*terrado con viguería = 0.5
replace   ATj=0.5  if (techos> 2  & techos <9)
*Teja, losa de concreto o viguetas con bovedilla = 1
replace   ATj=1    if (techos==9  | techos==10)
label var ATj "Adecuación de techos"

************************************
*Pisos 

gen       APj=0
*Tierra = 0
replace   APj=0    if (pisos==1)
*Cemento o firme = .5 
replace   APj=0.5  if (pisos==2)
*Madera, mosaico u otro recubrimiento
replace   APj=1    if (pisos==3)
label var APj "Adecuación de pisos"

********************************************************************************
* Indice compuesto calidad de la vivienda
* Ponderadores para se obtienen con base en los datos de COPLAMAR VIVIENDA
********************************************************************************

gen       ACVj=(APj*0.15) + (AMj*0.55) + (ATj*0.30)
label var ACVj "Ind compuesto calidad de la vivienda"

********************************************************************************
* Espacio disponible en la vivienda, se refiere al grado de hacinamiento, 
* considerándose como norma dos personas por dormitorio, un cuarto de usos 
* múltiples por cada 5 personas y cocina exclusiva (que no se utilice como dormitorio)
********************************************************************************

************************************
*Identificar cuartos hogar y dormitorios

rename  totcuart totcuart_orig
gen     totcuart=totcuart_orig

rename  cuadorm  cuadorm_orig
gen     cuadorm =cuadorm_orig

replace totcuart= cuadorm_orig  if totcuart_orig==99 & cuadorm_orig  !=99
replace cuadorm = totcuart_orig if cuadorm_orig ==99 & totcuart_orig !=99

replace totcuart=0 if totcuart_orig==99 & cuadorm_orig ==99
replace cuadorm =0 if totcuart_orig==99 & cuadorm_orig ==99

replace totcuart=0 if totcuart_orig==. & cuadorm_orig ==.
replace cuadorm =0 if totcuart_orig==. & cuadorm_orig ==.

gen     cuartosmultiococina=totcuart-cuadorm

*Se genera una variable para identificar  hogares donde la cocina también es 
*dormitorio: 1=si la cocina es exclusiva, es decir "sí no se usa como dormitorio"
*            0=duerme en la cocina 
*           
gen     KEh=0 if cocina==3 | cocina==9 | cocina==.
replace KEh=0 if cocina==1 & cuartosmultiococina==0
replace KEh=1 if cocina==1 & cuartosmultiococina>=1

gen       CCj= totcuart-KEh
label var CCj "Cuartos comparables viv cuart"
gen       CMj= (totcuart - (cuadorm + KEh))
label var CMj "Cuartos multiusos viv es (cuart - (dormi+ KEh))"

****************************************************
*Norma del total de cuartos de la vivienda
gen       CTj_N=1  + (0.75 * numpers) if (numpers >1)

*Si sólo recide una persona, la norma es 1
replace   CTj_N=1 if (numpers == 1)
label var CTj_N "Norma cuartos totales vivienda"

********************************************************
*Generar las variables normas para construir el indicador de carencia de la Vivienda
*Norma de dormitorios-> Un cuarto por dos personas
gen       Dh_N = numpers/2
label var Dh_N "Norma dormitorios hogar"

*Generar adecuación dormitorios por hogar
gen       ADh  = cuadorm / Dh_N
label var ADh "Ind adecuación dormitorios"
 
************************************
*Norma de cuartos multiusos de vivienda (un cuarto por cada cinco personas)
gen       CMj_N = numpers/5
label var CMj_N "Norma cuarto multiuso vivienda"

************************************
*Norma de dormitorios equivalentes                              
gen       DEh_N = (0.5) + Dh_N + (CMj_N*1.5)
label var DEh_N "Norma Dormitorios Equivalentes"

*Número de dormitorios equivalentes                                
gen       DEh = (KEh*0.5) + cuadorm + (CMj*1.5)
label var DEh "Número de Dormitorios Equivalentes"

gen       AEVh = DEh / DEh_N
label var AEVh "Adec espacio de la vivienda"

*******************************************************************
*Cálculo del indicador de espacio disponible en la vivienda
*******************************************************************

*Reescalación de indicador de adecuación de la vivienda
gen       AEVh_P = DEh                 if (numpers == 1 & AEVh <=1)
replace   AEVh_P =  1 + ((AEVh-1)/(2)) if (numpers == 1 & AEVh > 1)
replace   AEVh_P = DEh / DEh_N         if (numpers != 1 & AEVh <=1)
replace   AEVh_P =  1 + ((AEVh-1)/(2)) if (numpers != 1 & AEVh > 1)

label var AEVh_P "Reescal de Adec espacio viv"
replace   AEVh_P=2 if AEVh_P>=2

gen       HMDh = 1 - AEVh_P
label var HMDh "Hacinamiento multidimensional"


****************************************************************************
*Cálculo del consolidado de cantidad y calidad de la vivienda.
****************************************************************************

*Se toman en cuenta ambos indicadores, de espacio y calidad de la vivienda
gen       acevj = ACVj*AEVh_P
label var acevj "Ind de cant y calidad de la vivienda"

*Generar la variable de carencia
gen       ccevj= 1-acevj
label var ccevj "Ind carencia de cant y calidad de la vivienda"

*save "$tmp/ind_vivienda.dta", replace

********************************************************************************
* 2.2 Construcción y cálculo del indicador de bienes durables. Este indicador
*     compara un valor aproximado de los bienes durables en el  hogar, frente
*     a una norma del costo de una canasta de bienes durables  considerados necesarios
*     para el hogar. 
********************************************************************************

gen calgas=1  if (calentador_solar==3 | boiler==1)
gen bomag =1  if  bomba_agua==5
gen auto  =1  if  autoprop==7
gen radi  =1  if  radio==5
gen tele  =1  if  televisor==7 
gen refri =1  if  refrigerador==1
gen estu  =1  if  combustible==2
gen lavado=1  if  lavadora==3
gen compu =1  if  computadora==1
gen bici  =1  if  bicicleta==3
gen moto  =1  if  motocicleta==1 
gen celu  =1  if  celular==5
gen micro =1  if  horno==5
gen aire  =1  if  aire_acon==5
gen panel =1  if  panel_solar==7

*Cambiar los valores de missing a 0 para poder hacer la deflactación y la suma
recode calgas bomag auto radi tele refri estu lavado compu bici celu moto micro aire panel(.=0)
*Para verificar n
sum calgas bomag auto radi tele refri estu lavado compu bici celu moto micro aire panel 

*D1
*Dato externo 1 = Valores de artículos de vivienda deflactados al mes de agosto de 2015
  
gen Ncalgas=   1931.63  * calgas
gen Nbomag =    905.06  * bomag
gen Nauto  = 128081.07  * auto
gen Nradio =    612.95  * radi
gen Ntv1   =   3568.86  * tele 
gen Nrefri =   5571.61  * refri
gen Nestufa=   3367.02  * estu
gen Nlavado=   3818.75  * lavado
gen Ncompu =  11363.64  * compu
gen Nbici  =   1395.25  * bici
gen Nmoto  =  29105.49  * moto
gen Ncelu  =   1849.07	* celu
gen Nmicro =   1234.15  * micro
gen Naire  =   5813.79  * aire
gen Npanel =  15645.76  * panel

********************************************************************************
*Cálculo del indicador de bienes durables
********************************************************************************

*D2
*Dato externo 2= Canasta de bienes durables
*   NORMA es la suma del valor pesente de: Bicicleta, radiograbadora, televisor, 
*   computadora, estufa de gas, refrigerador, lavadora y celular. 
*   Siendo el denominador en 2015: 31,547.15

gen ABDj = (Ncalgas + Nbomag + Nauto + Nradio + Ntv1   + Nrefri + Nestufa + Nlavado +  ///
            Ncompu  + Nbici  + Nmoto + Ncelu  + Nmicro + Naire  + Npanel ) / (31547.15) 
 
label var   ABDj "Adec. Bienes Durables" 

*Reescalación de variable de bienes durables
gen         ABDj_P = ABDj
replace     ABDj_P = 1 + ((ABDj-1)/ 9) if (ABDj > 1 ) 
replace     ABDj_P = 2 if ABDj_P>=2
label var   ABDj_P "Resc Adec bienes durables"

*Generación de variable de carencia
gen         CBDj  = 1 - ABDj_P
label var   CBDj  "Carenc Resc Adec bienes durables"


********************************************************************************
*2.3 Construcción y cálculo del indicador de adecuacion sanitaria
*    Este indicador tiene dos componentes parciales:
*      *Adecuación de disponibilidad de agua
*      *Conexión al drenaje y excusado
********************************************************************************

************************************
* Adecuación de disponibilidad de agua: La norma corresponde a la 
* disponibilidad de agua dentro de la vivienda
gen       ag_disp=0
********************************************************************************

*no tienen agua entubada y no especificado
replace ag_disp=0 if  agua_entubada==3 | agua_entubada==9
replace ag_disp=0 if (agua_entubada==1 | agua_entubada==2) & (aba_agua_entu>=5 & aba_agua_entu<=7)
replace ag_disp=0 if (agua_entubada==1 | agua_entubada==2) & (aba_agua_entu==. | aba_agua_entu==9)

replace   ag_disp=1 if (agua_entubada==1 | agua_entubada==2) & aba_agua_entu==4 
replace   ag_disp=2 if (agua_entubada==2 & aba_agua_entu>=1 & aba_agua_entu<=3) 
replace   ag_disp=3 if (agua_entubada==1 & aba_agua_entu>=1 & aba_agua_entu<=3) 

********************************************************************************

gen       aaa = ag_disp/3
label var aaa "Adecuación forma de abasto hídrica"

************************************
* Conexión al drenaje y excusado: La norma corresponde al drenaje exclusivo 
* conectado a drenaje o fosa séptica
************************************

gen       dr=0
replace   dr=0 if (drenaje>=3 & drenaje<=9) | drenaje==.
replace   dr=1 if  drenaje==1 | drenaje==2
		   
gen       ADr =dr/1
label var ADr "Adecuación del drenaje"

*Generar índice de adecuación de excusado
************************************
*La norma es tener excusado, no compartido y con descarga directa de agua		
gen       EX=0

replace   EX=0 if (sersan ==3  | sersan==9  |  sersan  ==. ) 
replace   EX=0 if (conagua==3  | conagua==9 |  conagua ==. )
replace   EX=2 if (sersan ==1  | sersan==2) & (usoexc  ==1 &  conagua==2)
replace   EX=2 if (sersan ==1  | sersan==2) & (conagua ==1 |  conagua==2) & (usoexc==9  | usoexc  ==.)
replace   EX=3 if (sersan ==1  | sersan==2) & (usoexc  ==3 &  conagua==2)
replace   EX=3 if (sersan ==1  | sersan==2) & (conagua ==1 &  usoexc ==1)
replace   EX=4 if (sersan ==1  | sersan==2) & (conagua ==1 &  usoexc ==3)
gen       AEX = EX /4                            
label var AEX "Adecuación de excusado"   

*Generar indicador consolidado de adecuación sanitaria, con base en adecuación 
*de abasto hídrico, de drenaje y de excusado
gen       ASj = aaa * ADr * AEX   
label var ASj "Indicador consolidado de adecuación sanitaria"

*Generar indicador de carencia sanitaria
gen       CSj = 1 - ASj
label var CSj "Ind de carencia de adecuación sanitaria"

********************************************************************************
*2.4.1 Construcción y cálculo del indicador de servicio telefónico
********************************************************************************
*Generar el indicador conjunto de telefonía o celular
************************************
*La norma es tener al menos uno de los dos	
gen       ATlj  = .   
replace   ATlj  = 0    if (telefono == 4 & celular == 6) | telefono==9 | celular==9 |telefono==. | celular ==.
replace   ATlj  = 1    if (telefono == 3 | celular == 5)
replace   ATlj  = 1.5  if (telefono == 3 & celular == 5)
label var ATlj  "Adecuación teléfono"

gen       CTELJ = 1 - ATlj
label var CTELJ "Ind Caren del servicio telefonico"

********************************************************************************
*2.5 Construcción y cálculo del indicador de acceso a internet en la vivienda 
********************************************************************************

*Se crea la variable de internet en la vivienda 
rename internet internetoriginal
gen    internet=internetoriginal
label  var internet "Viviendas con internet"

*generar variable adecuación al internet 
gen     Ij= . 
replace Ij= 1 if  internet==7
replace Ij= 0 if (internet==8 | internet==9 |  internet==.)
label  var Ij  "Adecuación al internet" 

*se genera la variable electricidad dicotomica 
gen p_internet=Ij
*etiquetado de la variable
label var p_internet "Viviendas con internet dicotomico"

*Cración del indicador de carencia en el acceso a internet 
gen IVj= 1-Ij 
label var IVj "Ind Carencia de internet"

********************************************************************************
*2.6 Construcción y cálculo del indicador de adecuación energetica
********************************************************************************

*Generación indicador de disponibilidad de energía eléctrica
************************************
*La norma es cualquier opción en que sí tengan abasto de energía 
gen       AElj =0 if electricidad == 3  | electricidad == 9 |electricidad == .
replace   AElj =1 if electricidad == 1 
label var AElj "Adecuación energía eléctrica"

*Generación indicador de adecuación de combustible
************************************
* La norma es: utilizar gas o electricidad para cocinar 
 
gen       ck   =0 if combustible == 5 | combustible == 9 | combustible == .

replace   ck   =1 if combustible == 1 | combustible == 4

replace   ck   =3 if combustible == 2 | combustible == 3
gen       ACK  =(ck/3)
label var ACK  "Indicadores de adecuación combustible"

*Generación indicador conjunto de adecuación energética
gen       AEN  =ACK*(0.30) + AElj * (0.70)
label var AEN  "Indicadores de adecuación energetica"  

*Generación indicador de carencia energética
gen       CENJ =1-AEN
label var CENJ "Indicadores de carencia en adecuación energetica"


********************************************************************************
*2.7 Archivo con los  Indicadores de Adecuacion de la Vivienda 
********************************************************************************

save "$final/vivienda.dta", replace

********************************************************************************
* Módulo 3. Educación
*
*  3.1 Años de escolaridad
*  3.2 Condición de analfabetismo
*  3.3 Cálculo del indicador de adecuación y rezago educativo
*
********************************************************************************
*Abrir la base de Población original
use "$modificadas/poblacion.dta", clear

*Se eliminan los que no son miembros de la familia
drop if  parentesco>=600 & parentesco <720
drop if  parentesco==999

********************************************************************************
*3.1 Años de escolaridad
********************************************************************************

*Se remplazan a cero los "no especificado" en el nivel academico
replace nivacad =0  if nivacad  ==99

* Paso 1 : para todas aquellas personas que no responden grado de escolaridad se supone el 1 año según su nivel académico 

replace escolari=1  if escolari ==99

* Identificamos algunos casos con licenciatura o más que reportan más de seis años 
* de escolaridad,para fines del cálculo tomaremos 6 años de escolaridad como el máximo 
replace escolari=6  if escolari ==7  | escolari ==8

*Generar la variable rescgen, que muestra los años que han estudiado los individuos
*en conjunto de todos sus niveles escolares
gen rescgen=0

* Paso 2: si el nivel aprobado es 1, de preescolar, se reemplaza como el grado
* aprobado que tiene la persona, ya que no tiene antecedentes escolares que sumen
* años de escolaridad.
replace rescgen =escolari if nivacad  ==1


* Paso 3: Si el nivel aprobado es primaria, secundaria o bachillerato, se les suma
* una cantidad de años dada de manera que, en suma, se obtenga el número de años
* que llevan estudiando, tomando en cuenta preescolar.
replace rescgen=(2 + (escolari+1)) if nivacad==2 
replace rescgen=(3 + (escolari+6)) if nivacad==3
replace rescgen=(4 + (escolari+8)) if nivacad==4
replace rescgen=(4 + (escolari+8)) if nivacad==5


* Paso 4: Al grado "normal" o "carrera técnica", No se usa la variable antec_esc 
*
replace rescgen=10 if   nivacad==6  & escolari==1
replace rescgen=11 if   nivacad==6  & escolari==2
replace rescgen=12 if   nivacad==6  & escolari==3
replace rescgen=13 if   nivacad==6  & escolari==4
replace rescgen=14 if   nivacad==6  & escolari==5

replace rescgen=13 if   nivacad==7  & escolari==1
replace rescgen=14 if   nivacad==7  & escolari==2
replace rescgen=15 if   nivacad==7  & escolari==3
replace rescgen=16 if   nivacad==7  & escolari==4
replace rescgen=17 if   nivacad==7  & escolari==5

replace rescgen=13 if   nivacad==9  & escolari==1
replace rescgen=14 if   nivacad==9  & escolari==2
replace rescgen=15 if   nivacad==9  & escolari==3
replace rescgen=16 if   nivacad==9  & escolari==4
replace rescgen=17 if   nivacad==9  & escolari==5

replace rescgen=16 if   nivacad==8  & escolari==1
replace rescgen=17 if   nivacad==8  & escolari==2
replace rescgen=18 if   nivacad==8  & escolari==3
replace rescgen=19 if   nivacad==8  & escolari==4
replace rescgen=20 if   nivacad==8  & escolari==5


* Paso 5: Si el nivel aprobado es profesional, maestría o doctorado, solo se le 
* suman los años que llevan estudiando
replace rescgen=((7 * 2) + (escolari+1)) if nivacad==10 & (escolari > 0 & escolari <=6)
replace rescgen=((7 * 2) + (escolari+1)) if nivacad==11 & (escolari > 0 & escolari <=6)
replace rescgen=((8 * 2) + (escolari+4)) if nivacad==12 & (escolari >=1 & escolari <=3)
replace rescgen=((8 * 2) + (escolari+4)) if nivacad==13 & (escolari >=1 & escolari <=3)
replace rescgen=((9 * 2) + (escolari+4)) if nivacad==14

************************************
*Norma educativa de años estudiados, de acuerdo a la edad
replace edad=0 if edad==999

*Generar variable que identifica el año de nacimiento
gen a_nacimiento= 2020-edad
*Generación variable de norma educativa																	
gen 	normaedu= 0
*9 años  de educación equivalen a primaria
replace normaedu= 9      if 		a_nacimiento <= 1946
*12 años de educación equivalen a secundaria   				        				 	  
replace normaedu= 12     if 		a_nacimiento >= 1947 & a_nacimiento <= 1976
*15 años de educación equivalen a media superior   				        				 	 
replace normaedu= 15     if 		a_nacimiento >= 1977 & a_nacimiento <= 1996
replace normaedu= 15     if 		edad==.
*Norma específica para los nacidos después de 1977 y menores de 18 años
replace normaedu= edad-4 if 		a_nacimiento >= 1997 & edad > 4  & edad<19
label var normaedu "Norma educativa"

************************
*3.2 Condición de analfabetismo
************************

*Generar una nueva variable para condición de alfabetismo, donde normativamente
*se asume que mayores de ocho años analfabetas están en carencia				
gen       ali=.
replace   ali=. if  alfabet==9 
replace   ali=1 if  nivacad>=10 
replace   ali=1 if  alfabet==1
replace   ali=1 if  edad <8
replace   ali=0 if (alfabet==3 & edad >=8)
label var ali   "Condición de alfabetismo"

*Asistencia Escolar
*Generación de una variable recodificada de asistencia escolar
gen asis_esc_recoded=.
replace   asis_esc_recoded=. if  asisten==9
replace   asis_esc_recoded=1 if  nivacad>=10 
replace   asis_esc_recoded=1 if  asisten==1
replace   asis_esc_recoded=0 if  asisten==3
label var asis_esc_recoded   "asistencia escolar"

*Generar variable de norma de asistencia, aplica para los que tienen entre 4 y 17
*años cumplidos tienen que asistir a la escuela, en términos normativos. En caso 
*contrario, están en carencia
gen     normaasis=0																						
replace normaasis=1 if (edad >=4 & edad <= 17) 

********************************************************************************
* 3.3 Cálculo del indicador de adecuación y rezago educativo
********************************************************************************
*Generar de indicador de adecuación de educación
gen       anei=((rescgen + asis_esc_recoded)/ (normaedu + normaasis)) *   ali
replace   anei=((rescgen + asis_esc_recoded)/ (normaedu + normaasis)) if (edad>2 & edad<8)
label var anei "Adecuación de educación"

*Se reescala el indicador de anei (adecuación de educación), solo para los que
*están por arriba de la norma
*Generar valores de reescalación
recode edad (0/17=1)(18/29=2) (30/59=3)(60/197=4), gen(redad)
tabstat anei, s(mean min max) by (redad)

*Se introducen valores de reescalación
gen     anei_p=anei
replace anei_p = 1 + ((anei - 1) / (1.866667-1)) if ( anei>1 & (edad >= 18 & edad  <= 29) )
replace anei_p = 1 + ((anei - 1) / (2.416667-1)) if ( anei>1 & (edad >= 30 & edad  <= 59) )
replace anei_p = 1 + ((anei - 1) / (3.111111-1)) if ( anei>1 &  edad >  59)
replace anei_p = 2 if  anei_p>2
label var anei_p "Adecuación de educación del individuo"

*Indicador de carencia de educación
*Generar variable que identifique a los mayores a dos años
gen       mayores_dos_años =1 if edad >2
label var mayores_dos_años "Mayor de 2 años"

replace  anei_p =1 if  edad<=4
replace  anei_p =0 if (edad<=4) & asis_esc_recoded==0 

*Generar variable de rezago educativo individual
gen       rei = 1 - anei_p
label var rei "Rezago educativo individual"

*Guardar los cambios
keep id_viv id_persona rei rescgen anei_p factor
save "$final/educacion.dta", replace

*******************************************************************************
* Módulo 4. Salud y Seguridad Social
*
* 4.1 Generación de indicador de ingresos por pensiones y programas de adultos 
*     mayores
* 4.2 Indicadores para cálculo de acceso a salud
* 4.3 Variable de acceso a salud
* 4.4 Indicadores para cálculo de acceso a Seguridad Social
* 4.5 Variable de acceso a seguridad social 
*
********************************************************************************

********************************************************************************
*4.1 Generación de indicador de ingresos por pensiones y programas de adultos 
*    mayores
********************************************************************************

use "$final/hogaresNBI.dta", replace

*Se mantienen algunas variables en la base
keep id_viv factor upm ingr_jubpen ingr_ayugob jefe_edad
sort id_viv  
recode jefe_edad (999=0)

*Identificar cuántos hogares tienen ingresos por pensiones
gen       pension=0
replace   pension=1 if ingr_jubpen==7 
label var pension "Jubilación o pensión"

*Identificar cuántos hogares tienen ingresos por programas sociales
*Prospera, Oportunidades, Adultos mayores, PROCAMPO, etcétera
gen       prog_soc=0
replace   prog_soc=1 if ingr_ayugob==5 
label var prog_soc "Programa Social"

*Guardar la base de datos de pensiones a nivel persona
save "$tmp/pensiones_hogar.dta", replace

********************************************************************************
*Ingreso por transferencias y jubilaciones se simuló para jefes de hogar
********************************************************************************
use "$modificadas/poblacion.dta", clear
drop if  parentesco>=600 & parentesco <720
drop if  parentesco==999
recode   edad (999=0)

*Pegar base de pensiones
merge m:1 id_viv using "$tmp/pensiones_hogar.dta"
drop  _merge
 
*El dato de pension y programas sociales se registro a la vivienda para 
*el jefe o jefa del hogar
replace prog_soc=0 if parentesco!=101 & edad>=65
replace pension =0 if parentesco!=101 & edad>=65

*Guardar cambios
save "$tmp/salud_ss.dta", replace

********************************************************************************
*4.2 Indicadores para cálculo de acceso a salud
********************************************************************************

recode dhsersal1 (5 6=0.66)(1/3=1) (4 7 =1.1) (8=0.33) (.=0)(else=0), gen(dhsersal1_R)
recode dhsersal2 (5 6=0.66)(1/3=1) (4 7 =1.1) (8=0.33) (.=0)(else=0), gen(dhsersal2_R)

*Generar variable de acceso a salud
gen asaludi=   max(dhsersal1_R, dhsersal2_R)
recode asaludi (.=0)

********************************************************************************
*4.3 Variable de acceso a salud
********************************************************************************

gen     nodersali=0
replace nodersali=1 if asaludi==0

********************************************************************************
* 4.4 Variable de acceso a seguridad social 
*     Generar el identificador de acceso a SS por alguna de las instituciones
*     que contenga: 1 (inscrito como prestación laboral) o 2 (jubilación o 
*     invalidez) como su identificador:
*     IMSS=1, ISSSTE=2,  ISSTE ESTATAL=3; PEMEX, DEFENSA O MARINA=4, 
*     Seguro Popular=5,  Seguro Privado=6,       Otra Institución=7, 
*     No tiene derecho a servicios medicos=8,     No especificado=9
********************************************************************************
	
recode dhsersal1 (1=1) (2=2) (3=3) (4=4) (.=0)(else=0), gen(dhsalud1_R)
recode dhsersal2 (1=1) (2=2) (3=3) (4=4) (.=0)(else=0), gen(dhsalud2_R)
gen dhsalud=   max(dhsalud1_R, dhsalud2_R)

tab  dhsalud

*Identificar a quienes tienen actividad laboral
gen conac=0
replace conac=1 if (conact>=10 & conact <=20) 

*Identificar a quienes tienen afiliación a institución de seguridad social y actividad laboral
gen p1=0
gen p2=0
gen p3=0
gen p4=0
replace p1=1 if (dhsalud==1 & conac==1)
replace p2=1 if (dhsalud==2 & conac==1)
replace p3=1 if (dhsalud==3 & conac==1)
replace p4=1 if (dhsalud==4 & conac==1)

replace p1=1 if (dhsalud==1 & pension==1)
replace p2=1 if (dhsalud==2 & pension==1)
replace p3=1 if (dhsalud==3 & pension==1)
replace p4=1 if (dhsalud==4 & pension==1)

*A fin de determinar la cobertura se la SS, Se crea una variable para identificar 
*a los familiares directos del jefe de familia (pers1) y se aplican las reglas 
*establecidas en las leyes de SS vigentes:
*Parejas = pers2, hija(o)s=pers3,
*Padres  = pers4 o suegros=pers5
*Las variables pers1 a pers5,  toman valor de 1, e identifican al pariente que 
*existe en el hogar
*NOTA: se incluyen parejas del mismo sexo

gen paren1=.
replace paren1=1 if (parentesco>=100 & parentesco<200)
replace paren1=2 if (parentesco>=200 & parentesco<300)
replace paren1=3 if (parentesco>=300 & parentesco<400)
replace paren1=4 if  parentesco==401
replace paren1=5 if  parentesco==416
recode paren1(.=0)

gen pers1=1 if paren1==1
gen pers2=1 if paren1==2
gen pers3=1 if paren1==3
gen pers4=1 if paren1==4
gen pers5=1 if paren1==5

recode pers1-pers5 (.=0)

*Generar la variable "persm", que identifica a la persona que tiene 
*SERVICIO MEDICO DIRECTO por prestación laboral
gen       persm= p1 + p2 + p3 + p4
label var persm "Persona con prestación de SS laboral"


*Generar variable (segsocj) que identifica tipo de institución a la que se tiene
*acceso, para Jefes de familia:
*  1 = imss, 2 = issste federal y estatal, 4 = pemex
gen     segsocj=.
replace segsocj=3 if (persm>0 & paren1==1 )
replace segsocj=1 if (persm>0 & paren1==1 & dhsalud==1 )
replace segsocj=2 if (persm>0 & paren1==1 & (dhsalud==2 | dhsalud==3))

*Generar variable (segsocc) que identifica tipo de institución a la que se tiene
*acceso, para parejas
* 1 = imss, 2 = issste federal y estatal, 4= pemex
gen     segsocc=.
replace segsocc=3 if (persm>0 & paren1==2 )
replace segsocc=1 if (persm>0 & paren1==2 & dhsalud==1 ) 
replace segsocc=2 if (persm>0 & paren1==2 & (dhsalud==2 | dhsalud==3) )

*Generar variable (segsocc) que identifica si los hijos tienen acceso a SS
gen     segsoch=.
replace segsoch=1 if (persm>0 & (paren1==3 & edad>=16)) 
recode  segsocj segsocc segsoch (.=0)

*Generar variable que identifica si en el hogar hay personas con seguridad social,
*según parentesco
egen padre=   max(segsocj), by (id_viv)
egen conyuge= max(segsocc), by (id_viv)
egen hijoss=  max(segsoch), by (id_viv) 
egen per1=    max(pers1),   by (id_viv)
egen per2=    max(pers2),   by (id_viv)
egen per3=    max(pers3),   by (id_viv)
egen per4=    max(pers4),   by (id_viv)
egen per5=    max(pers5),   by (id_viv)

*Genera una variable que identifica a los hijos de asegurados que van a la escuela
* y por lo tanto acceden aa SS
*Para ISSSTE, los que son menores a 16 años, o entre 15 y 25 pero asisten a escuela
gen     h_b_issste=0
replace h_b_issste=1 if (((edad<16) | ((edad>15 & edad<25) & asisten==1)) & (paren1==3))

*Para IMSS,   los que son menores a 18 años, o entre 17 y 25 pero asisten a escuela
gen     h_b_imss  =0
replace h_b_imss  =1 if (((edad<18) | ((edad>17 & edad<25) & asisten==1)) & (paren1==3)) 

********************************************************************************
*4.5 Variable de acceso a seguridad social 
********************************************************************************
*Generar variable de Acceso a seguridad social 
gen asegsoci=0

*Paso 1: Se asigna valor según si es beneficiario de programa de adultos mayores:
*        0.25 a los que tienen PAM ("65 y más"), con excepción del prorgrama de 
*        la Ciudad de México, que se le asigna 0.5

replace asegsoci=0.5  if prog_soc==1 & edad>=68 

*Paso 2: Se reemplaza de acuerdo a ser asegurado o recibirlo por medio de la 
*        pareja, padre/madre o hijas/hijos
replace asegsoci=1 if  segsocj >0 | segsocc>0 | segsoch==1
replace asegsoci=1 if (padre  ==1 & h_b_imss  ==1) 
replace asegsoci=1 if (padre  ==2 & h_b_issste==1) 
replace asegsoci=1 if (conyuge==1 & h_b_imss  ==1) 
replace asegsoci=1 if (conyuge==2 & h_b_issste==1) 
replace asegsoci=1 if (padre   >0 & paren1    ==4) 
replace asegsoci=1 if (conyuge >0 & paren1    ==5) 


replace asegsoci=1 if (padre > 0 & per2==0 & per3==0 & paren1==4)
replace asegsoci=1 if (padre > 0 & per2==0 & h_b_issste==0 & paren1==4)
replace asegsoci=1 if (padre > 0 & per2==0 & h_b_imss==0 & paren1==4)

*Paso 3: Jefe cubre a cónyuge y viceversa
replace asegsoci=1 if (padre>0   & (conyuge==0 & paren1==2))
replace asegsoci=1 if (conyuge>0 & (padre  ==0 & paren1==1)) 

*Paso 4: Hijos con prestaciones cubren a  jefe y cónyuge
replace asegsoci=1 if (hijoss>=1 & padre  ==0 & paren1==1  ) 
replace asegsoci=1 if (hijoss>=1 & conyuge==0 & paren1==2  ) 
replace asegsoci=1 if (hijoss>=1 & segsoch==1 )
replace asegsoci=0 if (hijoss>=1 & segsoch==0 & segsocj==0 & segsocc==0 & (paren1==3 | paren1==0)) 

*Paso 5: Se identifica a las personas que tienen acceso indirecto a SS
*        Cualquiera que está afiliado y no tiene actividad laboral
replace asegsoci=1 if (dhsalud>0 & (conac==0))

*Se reemplaza a quienes tienen pensión por hogar: 
replace asegsoci=1 if  pension==1 & edad>=65

*Para aquellos con acceso directo y tienen seguridad social
replace asegsoci=1 if persm>=1 

*Etiquetar variables
label var asaludi "Acceso a servicios de salud, individuo"
label var asegsoci "Acceso a seguridad social, individuo"

* Se identifica con 1 a los trabajadores del hogar y los huespedes, y luego se
* retiran de la base                 
recode parentesco    /// 
       (600/620=1)      ///
	   (700/720=1)      ///
	   (else=0),        ///
	   gen (paren)
replace paren =0 if paren==.
keep if paren==0

*Generar variable de acceso a salud
gen ASI=.
replace ASI= asaludi
gen ASi_r = ASI
		
*Se crea variable de acceso a la seguridad social 
gen ASSI = .
replace ASSI = asegsoci


*Generar indicadores de carencia
gen CASI = 1 - (ASi_r)
label var CASI "Ind de carencia en salud"


*Generar indicador de carencia de Seguridad Social
gen CASSI = 1 - (ASSI) 
label var CASSI "Ind de carencia en seguridad social"

*Guardar cambios 
save "$tmp/salud_y_ss.dta", replace

*Guardar la base de datos
keep id_viv id_persona CASI CASSI 

*Guardar cambios 
save "$final/cass", replace

********************************************************************************
* Módulo 5. Tiempo
*
* 5.1 Generación de indicadores de carencia de cobertura de menores
* 5.2 Generación de indicador de requerimiento de trabajo doméstico
* 5.3 Generación de indicadores sobre discapacidad y disponibilidad
* 5.4 Generación de indicadores sobre trabajadores del hogar e integrantes disponibles
* 5.5 Calculo del indicador del tiempo
*
********************************************************************************

************************************************************************
* 5.1 Generación de indicadores de carencia de cobertura de menores
************************************************************************

***
***Identificación de prestación de guardería
***

*Abrir base de "Trabajo"
use "$modificadas/poblacion.dta", clear
destring parentesco, replace
drop if  parentesco>=600 & parentesco <720
drop if  parentesco==999

*Se modifica variable de prestación de guardería
gen pres_6_mod=1 if ( vacaciones==3 & servicio_medico==5 &sar_afore==3 &  utilidades==7) 
replace pres_6_mod=0 if  pres_6_mod==.


*Quitar missings de hstrmesp
gen  hstrmesp= hortra
replace hstrmesp=. if  hstrmesp==0
replace hstrmesp=. if hstrmesp==999 
*Generar variables de parentesco y sexo a modificar
destring parentesco sexo, replace

*Generar variable de guardería
gen guard=0
replace guard=1 if pres_6_mod==1

*Generar variable que identifica menores de 10 años
gen menorh10=0
replace menorh10=1 if edad<=10

*Generar variable que identifica trabajadores del hogar
gen trab_hogar=0
replace trab_hogar=1 if ( parentesco >= 601 &  parentesco <= 612)

*Colapsar Indicador de Trabajadores del hogar y agregar a la misma base
egen trab_hogar_h=sum(trab_hogar), by(id_viv)

*Recodificar variable de parentesco, 1 identifica a los no familiares
recode parentesco      /// 
       (400/470=1)     ///
	   (700/999997=1),  ///
       gen (paren) 
replace paren=0 if paren !=1
keep if paren==0	   
		
*Generar identificador de madre
gen esmama=0
replace esmama=1 if ((parentesco== 101 | ( parentesco>=201 &  parentesco<= 203 )) & sexo== 3)

*Generar identificador de hija
gen esmama_hija=0
replace esmama_hija=1 if (( parentesco>=301 &  parentesco<= 304 ) & sexo==3)

*Crear y modificar identificador de asistencia a la escuela
destring asisten, replace
recode asisten (3=0) (.=0) , gen(asis_esc_modif)
tab asis_esc_modif asisten
tab asis_esc_modif

*Identificador de mujeres que tienen prestación de guardería
gen der_guard=0
gen der_guard_hija=0
replace der_guard=1 if (guard==1 & esmama== 1) 
replace der_guard_hija=1 if (guard==1 & esmama_hija== 1) 

*Generar variable de derecho a guardería a nivel hogar, aún por madre e hija
egen der_guard_max=max(der_guard), by(id_viv)
egen der_guard_hija_max=max(der_guard_hija), by(id_viv)

*Generar identificador de menores de hasta 5 años
gen menorh5=0
replace menorh5=1 if edad <= 5
label var menorh5 "Menor de hasta cinco" 
replace menorh5 =0 if menorh5==.

*Identificador de menores que asisten a escuela o guardería
gen menor_asis_esc=0
replace menor_asis_esc=1 if (asis_esc_modif== 1 & menorh10== 1)
replace menor_asis_esc=1 if (der_guard_max==1 & (parentesco>=301 & parentesco<= 305) &  menorh5== 1)
replace menor_asis_esc=1 if (der_guard_hija_max== 1 & parentesco== 408 &  menorh5== 1)

*Identificar pob de 15 a 69 años
gen n15_69 = 0 
replace n15_69 =1 if (edad>= 15 & edad< 70)

*Identificar pob de 12 a 14 años
gen d_12_14=0
replace d_12_14=6/48 if (edad >= 12 & edad <= 14) 
label var d_12_14 "Disponible 12 a 14 años"

*Identificar pob de 70 a 79 años
gen d_70_79=0
replace d_70_79=16/48 if  (edad >= 70 & edad <= 79) 
label var d_70_79 "Disponible 70 a 79 años"

*Colapsar y renombrar variables
collapse (sum) n15_69 hstrmesp menorh10 menor_asis_esc d_70_79 d_12_14 (max) trab_hogar_h, by(id_viv)
label var n15_69 "Total personas entre 15 y 69 en hogar"
label var menorh10 "Menores de hasta 10 años en el hogar" 

rename hstrmesp wj 
label var wj "Total de horas de trabajo por hogar (ocup princ y sec)"

rename trab_hogar_h JTH
label var  JTH "Trabajadores del hogar"

rename menor_asis_esc asis_esch 
label var asis_esch "Menores de 11 años en hogar que asisten escuela o guardería"  

rename d_70_79 dj70_79
label var dj70_79 "Disponible 70 a 79 años"

rename d_12_14 dj12_14
label var dj12_14 "Disponible 12 a 14 años"

*Crear variable de cobertura de menores (en escuela o guarderías)
gen cobertura_menores=0
replace  cobertura_menores=asis_esch/menorh10 if menorh10 > 0
label var cobertura_menores "Cobertura educativa de menores de 11"

*Generar variable de carencia de cuidado de menores
gen CASCMj= (1-cobertura_menores)*2
label var CASCMj "Carencia cuidado de menores"

*Verificar que no se le esté imputando carencia en el cuidado de menores a hogares que no tienen menores
replace CASCMj=0 if (menorh10==0 & CASCMj==2)

*Guardar base de datos
save "$tmp/cascm.dta", replace


************************************************************************
* 5.2 Generación de indicador de requerimiento de trabajo doméstico
************************************************************************
*se crea tm_hog
use "$modificadas/poblacion.dta", clear
*Eliminar los folios de los que no son miembros de la familia en el hogar
destring parentesco, replace
drop if  parentesco>=600 & parentesco <720
drop if  parentesco==999
gen x=1 
collapse (sum) x, by (id_viv) 
save "$tmp/tam_hog.dta", replace 

*Trabajar base temporal proveniente del módulo 1 "NBI"
use "$modificadas/viviendas.dta", clear
merge 1:1 id_viv using "$tmp/tam_hog.dta"
renam x tam_hog
drop _merge 

*Disponibilidad del agua 
destring agua_entubada, replace
 recode agua_entubada (9 . =3), gen(agu)
gen AAj=0 if agu==1 
replace AAj=.66 if agu==2 
replace AAj=2 if agu==3

*Recodificación de variables de bienes del hogar
recode refrigerador horno lavadora autoprop motocicleta (1 3 5 7=1) (2 4 6 8 . 9 =0)
label var refrigerador "¿Tiene refrigerador?"
label var horno "¿Tiene horno de microondas?"
label var lavadora "¿Tiene lavadora?"
label var autoprop  "Auto"
label var motocicleta  "Moto"

*Indicador de vehiculo motorizado
gen vehicmot = 0
label var vehicmot "¿Tiene vehiculo motorizado?"
replace vehicmot = 1 if (autoprop==1 | motocicleta==1)  

*Indicador de equipo domestico 
gen equipdom= 0
replace equipdom= refrigerador + horno + lavadora
label var equipdom "¿Tiene equipo doméstico?"

*Indicador de carencia de equipo ahorrador de trabajo doméstico 
gen CEATDj=0
label var CEATDj "Carencia de equipo ahorrador de trabajo doméstico"

*Se pondera el indicador de acuerdo a disponibilidad de vehículo motorizado o equipo doméstico
replace CEATDj = 0  if (equipdom == 3 & vehicmot == 1)
replace CEATDj = 0  if (equipdom == 3 & vehicmot == 0)
replace CEATDj = 0  if (equipdom == 2 & vehicmot == 1)
replace CEATDj = 1  if (equipdom == 2 & vehicmot == 0)
replace CEATDj = 1  if (equipdom == 1 & vehicmot == 1)
replace CEATDj = 1  if (equipdom == 0 & vehicmot == 1)
replace CEATDj = 2  if (equipdom == 1 & vehicmot == 0)
replace CEATDj = 2  if (equipdom == 0 & vehicmot == 0)

*Se unen las bases creadas anteriormente
merge 1:1 id_viv using "$tmp/cascm.dta"

*Indicador de la intensidad del trabajo doméstico
gen ITDj=.
replace ITDj = ((AAj + CEATDj)/2) if menorh10==0
replace ITDj = ((AAj + CEATDj + CASCMj)/3)  if menorh10>0

*Indicador de la intensidad del trabajo doméstico por estratos
gen       ITDj_r=.
replace   ITDj_r=0 if ITDj<=0.5
replace   ITDj_r=1 if ITDj>0.5 & ITDj<=1.5
replace   ITDj_r=2 if ITDj>1.5 
label var ITDj_r "Intensidad trab dom por estratos"
drop ITDj
rename ITDj_r ITDj

*Se agrupa tamaño de hogar para un mejor manejo de la variable
recode tam_hog (1 2=1)(3 4=3)(5 6=5)(7/99997=7), gen(rank_nhog)
label var rank_nhog "Recodificación de tamaño de hogar" 

***
***Indicador de requerimiento de jornada de trabajo doméstico
***
gen RTDj=.
replace RTDj = 0.7 if (menorh == 0 & ITDj == 2 & rank_nhog == 1)
replace RTDj = 0.9 if (menorh == 0 & ITDj == 2 & rank_nhog == 3)
replace RTDj = 1.1 if (menorh == 0 & ITDj == 2 & rank_nhog == 5)
replace RTDj = 1.3 if (menorh == 0 & ITDj == 2 & rank_nhog == 7)

replace RTDj = 0.5 if (menorh == 0 & ITDj == 1 & rank_nhog == 1)
replace RTDj = 0.7 if (menorh == 0 & ITDj == 1 & rank_nhog == 3)
replace RTDj = 0.9 if (menorh == 0 & ITDj == 1 & rank_nhog == 5) 
replace RTDj = 1.1 if (menorh == 0 & ITDj == 1 & rank_nhog == 7) 

replace RTDj = 0.3 if (menorh == 0 & ITDj == 0 & rank_nhog == 1) 
replace RTDj = 0.5 if (menorh == 0 & ITDj == 0 & rank_nhog == 3) 
replace RTDj = 0.7 if (menorh == 0 & ITDj == 0 & rank_nhog == 5) 
replace RTDj = 0.9 if (menorh == 0 & ITDj == 0 & rank_nhog == 7) 

replace RTDj = 1.2 if (menorh  > 0 & ITDj == 2  & rank_nhog == 1) 
replace RTDj = 1.4 if (menorh  > 0 & ITDj == 2  & rank_nhog == 3) 
replace RTDj = 1.6 if (menorh  > 0 & ITDj == 2  & rank_nhog == 5) 
replace RTDj = 1.8 if (menorh  > 0 & ITDj == 2  & rank_nhog == 7) 

replace RTDj = 1.0 if (menorh  > 0 & ITDj == 1  & rank_nhog == 1) 
replace RTDj = 1.2 if (menorh  > 0 & ITDj == 1  & rank_nhog == 3) 
replace RTDj = 1.4 if (menorh  > 0 & ITDj == 1  & rank_nhog == 5) 
replace RTDj = 1.6 if (menorh  > 0 & ITDj == 1  & rank_nhog == 7) 

replace RTDj = 0.8 if (menorh  > 0 & ITDj == 0  & rank_nhog == 1) 
replace RTDj = 1.0 if (menorh  > 0 & ITDj == 0  & rank_nhog == 3) 
replace RTDj = 1.2 if (menorh  > 0 & ITDj == 0  & rank_nhog == 5) 
replace RTDj = 1.4 if (menorh  > 0 & ITDj == 0  & rank_nhog == 7) 

label var RTDj "Requerimiento de jornada de trabajo doméstico" 

*Guardar la base de datos
keep ent nom_ent mun nom_mun loc50k nom_loc id_viv factor cobertura_menores ITDj ///
n15_69 dj12_14 dj70_79 wj menorh10 JTH RTDj RTDj 
save "$tmp/ocuph.dta", replace

************************************************************************
* 5.3 Generación de indicadores sobre discapacidad y disponibilidad
************************************************************************

***
***Identificador de población que tiene trabajo, pero no trabajó mes pasado, estudiantes e incapacitados  
***
use "$modificadas/poblacion.dta", clear
*Eliminar los folios de los que no son miembros de la familia en el hogar
destring parentesco, replace
drop if  parentesco>=600 & parentesco <720
drop if  parentesco==999

*Indicador ocupados de 12 a 79 años 
keep if edad>=12 & edad<80

*Indicador ONT (Ocupados que No Trabajaron) causa por la que no trabajó el mes pasado 
gen ont=0
replace ont =1 if conact==20  	
label var ont "Ocupados que no trabajaron" 

*Indicador de ocupados que no trabajaron de 12 a 79 años
gen 		ONT=0
replace 	ONT=6/48  if  (ont == 1 & (edad >= 12 & edad  <= 14))
replace 	ONT=16/48 if  (ont == 1 & (edad >= 70 & edad  <= 79)) 
replace 	ONT=1     if  (ont == 1 & (edad >= 15 & edad  <= 69))
label var 	ONT "Ocupados que no trabajaron de 12 a 79 años" 

*Indicador de 15 a 79 años que asisten a la escuela 
gen EST=0
replace  EST = 1 if ((edad >= 15 & edad < 80) & asisten == 1)
label var EST "Estudiantes"

*Indicador de personas con discapacidad y que por esa razón no trabajan
gen C_Disc_a=0
replace C_Disc=1 if conact==70
label var C_Disc "Personas con discapacidad y que por esa razón no trabajan"

*Indicador de personas con discapacidad  de 12 a 79 años y que por esa razón no trabajan
gen 		C_Disca=0
replace   	C_Disca=6/48  	if  (C_Disc_a==1 & (edad >= 12 & edad  <= 14))
replace   	C_Disca=16/48 	if  (C_Disc_a==1 & (edad >= 70 & edad  <= 79))
replace   	C_Disca=1	 	if  (C_Disc_a==1 & (edad >= 15 & edad  <= 69))
label var 	C_Disca "Personas con discapacidad y que por esa razón no trabajan de 12 a 79"

*Se colapsan las variables a nivel hogar
collapse (sum) C_Disca EST ONT, by(id_viv)

label var C_Disca "Número de personas con discapacidad"
label var EST "Número de estudiantes en el hogar"
label var ONT "Número de ocupados que no trabajó mes pasado"

save "$tmp/jorexc.dta", replace

************************************************************************
* 5.4 Generación de indicadores sobre trabajo doméstico
************************************************************************

*Utilizar base creada anteriormente
use "$tmp/factexp.dta",clear 
merge 1:1 id_viv  using "$tmp/ocuph.dta"
drop _merge

*Generar indicador de jornadas de trabajadores del hogar
label var JTH "Jornadas desempeñadas por trabajadores del hogar"

*Generar con la base jorexc
merge 1:1 id_viv using "$tmp/jorexc.dta"
drop _merge

*Se reemplanzan valores perdidos por cero
replace ONT=0 		if ONT==.
replace EST=0 		if EST==.
replace C_Disca=0 	if C_Disca==.
replace RTDj=0 		if RTDj==.
replace JTH=0 		if JTH==.  

*Generar indicador de jornadas de trabajo que no se suman al total del hogar
gen hj= ONT + (EST*0.5833) +  C_Disca
label var hj "Jornadas de trabajo excluidas en el hogar"
replace hj=0 if hj==. | hj<0

*Generar indicador neto de disponibilidad de jornadas de trabajo doméstico por hogar
gen 	kj= (n15_69 + dj12_14 + dj70_79) - hj
replace kj=0 if kj==. | kj<0
label var kj "Horas disponibles de trabajo por hogar"

**************************************************
* 5.5 Calculo del indicador del tiempo
**************************************************

***
***Generación de indicador final de tiempo
***
gen ett=0

replace ett= ((1 + wj) + ((RTDj - JTH) * 48)) /   (kj * 48) 	if (kj >  0 & RTDj >= JTH) 
replace ett= ((1 + wj)                        /   (kj * 48))  	if (kj >  0 & RTDj <  JTH) 
replace ett= ((1 + wj) + ((RTDj - JTH) * 48)) /(1+(kj * 48)) 	if (kj <= 0 & RTDj >= JTH) 
replace ett= ((1 + wj)                        /(1+(kj * 48)))   if (kj <= 0 & RTDj <  JTH) 

replace ett=0.1 if ett>0 & ett<=0.5
replace ett=2 if ett>2 

*Generación de indicador de trabajo doméstico
gen trab_dom = (RTDj - JTH)*48 

*Guardar una base que contiene todas las variables 
save "${tmp}/indocu.dta", replace 

*Se seleccionan algunas variables y se guarda una base con solo esas variables
keep id_viv mun ent ur_rur_2500  ett trab_dom
save "$final/etj.dta", replace 

********************************************************************************
* Módulo 6. Cálculo del Indicador de Necesidades Básicas Insatisfechas
* 6.1 Pegar las bases finales y quedarse con una sola de trabajo
* 6.2 Calcular NBI
* 6.3 Generar los estratos del NBI
* 6.4 Guardado de base final
********************************************************************************

********************************************************************************
* 6.1 Pegado de bases
********************************************************************************

*Abrir base de población 
use "$modificadas/poblacion.dta", clear

*Eliminar los folios de los que no son miembros de la familia en el hogar
destring parentesco, replace
drop if  parentesco>=600 & parentesco <720
drop if  parentesco==999

*Pegar con base de factor	
merge m:1 id_viv using "$tmp/factexp.dta"
drop _merge

*Pegar con la base de vivienda
merge m:1 id_viv  using "$final/vivienda.dta"
drop _merge

*Pegar con la base de educación
merge 1:1 id_viv id_persona  using "$final/educacion.dta"
drop _merge

*Pegar con la base Salud y Seguridad Social
merge 1:1 id_viv id_persona  using "$final/cass.dta"
drop _merge

*Pegar con la base de Tiempo
merge m:1 id_viv  using "$final/etj.dta"
drop _merge

*Mantener con el concepto de viviendas particulares
drop if clavivp>=7 & clavivp<=9

********************************************************************************
*Guardar una base final con las bases pegadas para trabajar y hacer calculos
save "$final/basefinalNBI_pegadas.dta", replace
********************************************************************************

********************************************************************************
* 6.2 Cálculos de NBI
********************************************************************************

*Abrir base con todas las demas ya pegadas
use "$final/basefinalNBI_pegadas.dta", clear

*Generar indicador de NBI
gen nbi= (ccevj*.328) + (CSj*.037) + (CENJ*.028) + (CTELJ*.010) + (IVj*.020) +  (CBDj *.058) + (rei*.236) + (CASSI*.1415) + (CASI*.1415)
label variable nbi "Indice global NBI"

*** Etiqueta de estratos
label define estratos 6"Estrato alto" 5"Estrato medio" 4"Satisfaccion mínima" 3"Pobreza moderada" 2"Pobreza alta" 1"Pobreza muy alta"

*se genera un bucle para las creación de las siguientes variables CCEVj CBDj CSj TELj CAEj rei CASSI CASI nbi IVj
*se generan los estratos del NBI 
foreach var of varlist  ccevj CSj CENJ CTELJ IVj CBDj  rei CASSI CASI nbi  {
 gen E_`var'=. 
 replace E_`var'=6 if `var'  <=-0.5
 replace E_`var'=5 if (`var'> -0.5 & `var'<= -.1)
 replace E_`var'=4 if (`var' > -0.1 & `var' <= 0) 
 replace E_`var'=3 if (`var' > 0 & `var' <= (1/3)) 
 replace E_`var'=2 if (`var' > (1/3) & `var' <= .5) 
 replace E_`var'=1 if (`var' > .5 & `var' <= 1)  
label values  E_`var' estratos
 }
*

* Estratos de tiempo
gen E_ett=.
replace E_ett=6 if  ett <= 0.5
replace E_ett=5 if (ett >  0.5   & ett <= .9)   
replace E_ett=4 if (ett >  0.9   & ett <= 1)    
replace E_ett=3 if (ett >  1     & ett <= 1.333)
replace E_ett=2 if (ett >  1.333 & ett <= 1.5)
replace E_ett=1 if (ett >  1.5   & ett <= 2)
label values E_ett estratos

*Se etiquetan los estratos estratos de NBI 
label var E_ccevj  "Estratos de Calidad y Espacio de la Vivienda"
label var E_CBDj   "Estrato de carencia de bienes durables"
label var E_CSj    "Estrato de adecuación sanitaria"
label var E_CTELJ  "Estrato de carencia de teléfono"
label var E_IVj    "Estratos de acceso a internet"
label var E_CENJ   "Estrato de carencia energética"
label var E_rei    "Estrato de rezago educativo" 
label var E_CASSI  "Estratos de Acceso a Seguridad Social"
label var E_CASI   "Estratos de Acceso a Salud"
label var E_nbi    "Estratos de Necesidades Básicas Insatisfechas"
label var E_ett    "Estratos del tiempo"

 *pobreza 
foreach var of varlist E_ccevj-E_ett {
gen pobreza_`var'=. 
replace pobreza_`var'= 0 if `var'>=4  
replace pobreza_`var'= 1 if `var'<=3
label  var pobreza_`var' "pobreza `var'"
}
*

*pobreza extrema  
foreach var of varlist E_ccevj-E_ett {
gen pobreza_ext_`var'=. 
replace pobreza_ext_`var'= 0 if `var'>=3  
replace pobreza_ext_`var'= 1 if `var'<=2
label var pobreza_ext_`var' "pobreza extrema`var'"
}
*
 
save "$tmp/finalNBI_2020.dta", replace

********************************************************************
* 5.4 Guardado de base final
********************************************************************

*selección de variables

keep id_viv id_persona numper upm estrato factor tamloc ur_rur_2500 tam_hog ent mun alcaldia  ///
     sexo edad parentesco situa_conyugal perte_indigena hlengua elengua alfabet asisten       ///
	 dhsersal1 dhsersal2 nbi  E_* 

order id_viv id_persona numper upm estrato factor tamloc ur_rur_2500 tam_hog ent mun alcaldia  ///
      sexo edad parentesco situa_conyugal perte_indigena elengua hlengua  alfabet asisten      ///          
      dhsersal1 dhsersal2 nbi  E_* 

*Etiquetar variables	 
label var	id_viv	        "Identificador único de la vivienda"
label var	id_persona      "Identificador único de la persona"
label var	numper	        "Número de persona"
label var	upm	            "Unidad primaria de muestreo"
label var	estrato	        "Estrato de diseño muestral"
label var   factor          "Factor de expansión"
label var	tamloc	        "Tamaño de localidad"
label var	ur_rur_2500	    "Localidades urbanas o rurales"
label var	tam_hog	        "Tamaño del hogar"
label var	ent 	        "Entidad"
label var	mun   	        "Municipio"
label var   alcaldia        "Alcaldía"
label var	sexo	        "Sexo"
label var	edad	        "Edad"
label var	parentesco   "Parentesco"
label var	situa_conyugal  "Situación conyugal"
label var	perte_indigena  "Auto adscripción étnica"
label var	elengua	        "Entiende lengua indígena"
label var	hlengua 	    "Hablante indígena"
label var	alfabet 	    "Alfabetismo"
label var	asisten 	    "Asistencia a la escuela"
label var	dhsersal1 	    "Afiliación a servicios de salud (primer opción)"
label var	dhsersal2 	    "Afiliación a servicios de salud (segunda opción)"
label var	nbi	            "Índice global NBI"
label var   E_ccevj         "Estratos de Calidad y Espacio de la Vivienda"
label var   E_CBDj          "Estrato de carencia de bienes durables"
label var   E_CSj           "Estrato de adecuación sanitaria"
label var   E_CTELJ         "Estrato de carencia de teléfono"
label var   E_IVj           "Estratos de acceso a internet"
label var   E_CENJ          "Estrato de carencia energética"
label var   E_rei           "Estrato de rezago educativo" 
label var   E_CASSI         "Estratos de Acceso a Seguridad Social"
label var   E_CASI          "Estratos de Acceso a Salud"
label var   E_nbi           "Estratos de Necesidades Básicas Insatisfechas"
label var   E_ett           "Estratos del tiempo"

*Ciudad de México
foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI  E_ett  {
 tab `var'  [iw=factor] 
 }

 *Azcapotzalco													
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI E_ett   {
 tab `var'  [iw=factor] if mun==2
 }
 
*Coyoacán 
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI  E_ett  {
 tab `var'  [iw=factor] if mun==3
 }
 
 
*Cuajimalpa de Morelos	
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI  E_ett  {
 tab `var'  [iw=factor] if mun==4
 }
 
*Gustavo A. Madero	
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI  E_ett  {
 tab `var'  [iw=factor] if mun==5
 }
 
*Iztacalco	
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI   E_ett {
 tab `var'  [iw=factor] if mun==6
 }
 
*Iztapalapa	
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI  E_ett  {
 tab `var'  [iw=factor] if mun==7
 }
 
*La Magdalena Contreras	
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI   E_ett {
 tab `var'  [iw=factor] if mun==8
 }
 
*Milpa Alta	
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI  E_ett  {
 tab `var'  [iw=factor] if mun==9
 }
 
*Álvaro Obregón	
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI  E_ett  {
 tab `var'  [iw=factor] if mun==10
 }
 
*Tláhuac   	
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI  E_ett  {
 tab `var'  [iw=factor] if mun==11
 }
 
*Tlalpan	
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI  E_ett  {
 tab `var'  [iw=factor] if mun==12
 }
 
*Xochimilco	
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI  E_ett  {
 tab `var'  [iw=factor] if mun==13
 }
 
*Benito Juárez 	
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI  E_ett  {
 tab `var'  [iw=factor] if mun==14
 }
 
*Cuauhtémoc 
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI E_ett   {
 tab `var'  [iw=factor] if mun==15
 }
  	
*Miguel Hidalgo	
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI  E_ett  {
 tab `var'  [iw=factor] if mun==16
 }
 
*Venustiano Carranza
 foreach var of varlist  E_nbi E_ccevj E_CBDj E_CSj E_CTELJ ///
    E_IVj E_CENJ E_rei E_CASI E_CASSI  E_ett  {
 tab `var'  [iw=factor] if mun==17
 }
 
 
*Guardar la base
save "$final/finalNBI_2020.dta", replace




